# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

%global module_version 1.5

Summary:	Perl interface to the uulib library (a.k.a. uudeview/uuenview)
Name:		perl-Convert-UUlib
Version:	1.50
Release:	2.%{__distinit}%{__distvers}
License:	GPLv2+
Group:		Development/Libraries
Url:		http://search.cpan.org/dist/Convert-UUlib/
Source0:	http://search.cpan.org/CPAN/authors/id/M/ML/MLEHMANN/Convert-UUlib-%{module_version}.tar.gz
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 6 || 0%{?rhel} > 5
BuildRequires:	perl-devel
%endif
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(Canary::Stability)
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(DynaLoader)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
# (none)
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

# Don't "provide" private Perl libs
%{?perl_default_filter}

%description
Convert::UUlib - Perl interface to the uulib library (a.k.a.
uudeview/uuenview).

%prep
%setup -q -n Convert-UUlib-%{module_version} 

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} %{buildroot}
 
%check
make test

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license COPYING*
%else
%doc COPYING*
%endif
%doc README* Changes doc/* example-decoder
%{perl_vendorarch}/Convert/
%{perl_vendorarch}/auto/Convert/
%{_mandir}/man3/Convert::UUlib.3*

%changelog
* Thu Aug 11 2016 Paul Howarth <paul@city-fan.org> - 1.50-2
- BR: perl-devel and perl-generators where available
- Simplify find commands using -empty and -delete

* Sun Jul 12 2015 Paul Howarth <paul@city-fan.org> - 1.50-1
- Update to 1.50
  - Fix a heap overflow
  - On systems that support it (POSIX + mmap + map_anonymous), allocate all
    dynamic areas via mmap and put four guard pages around them, to catch
    similar heap overflows safely in the future
  - Find a safer way to pass in CC/CFLAGS to uulib
  - Added stability canary support
- Classify buildreqs by usage
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Thu Jun  7 2012 Paul Howarth <paul@city-fan.org> - 1.40-3
- BR: perl(Carp) and perl(Exporter)
- Don't need to remove empty directories from buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Wed Jun 22 2011 Paul Howarth <paul@city-fan.org> - 1.40-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Sun May 29 2011 Paul Howarth <paul@city-fan.org> - 1.40-1
- Update to 1.4
  - Avoid a classical buffer overflow in case a progress message is too long
  - This release adds dependencies for snprintf/vsnprintf
  - Some uuencode encoders do not generate a final "space" line before the
    "end" marker, so do not rely on the line to be there
- Nobody else likes macros for commands

* Wed Dec 15 2010 Paul Howarth <paul@city-fan.org> - 1.34-1
- Update to 1.34
  - Fix a one-byte-past-end-write buffer overflow in UURepairData
  - Quoted-printable decoding was completely broken; try a fix

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 1.33-4
- Rebuild for perl 5.12.1 in Rawhide

* Tue Jun  8 2010 Paul Howarth <paul@city-fan.org> - 1.33-3
- Fix dist tag for RHEL-6 Beta

* Thu Feb 25 2010 Paul Howarth <paul@city-fan.org> - 1.33-2
- Dist tag for Rawhide no longer needs special-casing

* Wed Oct 28 2009 Paul Howarth <paul@city-fan.org> - 1.33-1
- Update to 1.33 (handle yEnc files with part end=0 and total= more gracefully)

* Thu Sep 17 2009 Paul Howarth <paul@city-fan.org> - 1.32-1
- Update to 1.32 (exec permission on configure script fixed)

* Wed Sep 16 2009 Paul Howarth <paul@city-fan.org> - 1.31-1
- Update to 1.31
  - system versions of case-insensitive string functions not used
- Use %%{?perl_default_filter} for perl shared objects
- Fix missing exec permission on configure script

* Tue Sep  1 2009 Paul Howarth <paul@city-fan.org> - 1.30-1
- Update to 1.3 (RPM package version 1.30 to avoid epoch bump)
  - Multiple performance improvements

* Fri Aug 28 2009 Paul Howarth <paul@city-fan.org> - 1.12-3
- Improve requires/provides filter to not filter out more than necessary

* Sun Mar  1 2009 Paul Howarth <paul@city-fan.org> - 1.12-2
- Filter out unwanted provides for perl shared objects
- Update to SLES-compatible dist tag macros

* Mon Oct 13 2008 Paul Howarth <paul@city-fan.org> - 1.12-1
- Update to 1.12

* Fri Jun 13 2008 Paul Howarth <paul@city-fan.org> - 1.11-1
- Update to 1.11
- Clarify license as GPL version 2 or later (from uulib)

* Thu May 31 2007 Paul Howarth <paul@city-fan.org> - 1.09-1
- Update to 1.09
- BuildRequire perl(ExtUtils::MakeMaker)

* Mon Dec 18 2006 Paul Howarth <paul@city-fan.org> - 1.08-1
- Update to 1.08

* Mon Dec 11 2006 Paul Howarth <paul@city-fan.org> - 1.07-1
- Update to 1.07
- Fix dist tag for development builds
- Fix argument order for find with -depth

* Thu Aug 31 2006 Paul Howarth <paul@city-fan.org> - 1.06-2
- Disregard distribution sub-release number in dist tag
- Define %%{__id_u} in a more portable way

* Tue Dec  6 2005 Paul Howarth <paul@city-fan.org> - 1.06-1
- Update to 1.06
- Simplify distribution-detection
- Remove macros %%__perl_package and %%perl_version
- Use search.cpan.org URLs
- Add example-decoder as %%doc
- Simplify compiler optimization flag settings
- Remove buildroot unconditionally in %%clean and %%install
- Don't use macros in paths for build-time commands, hardcode them instead

* Thu Jul  7 2005 Paul Howarth <paul@city-fan.org> - 1.051-2
- Rewrite spec file in (mainly) Fedora Extras style
- Include full URL for source
- Fix URL
- Use MODULE_COMPAT dependency style and remove explicit perl dependency
- Add doc/*

* Wed Mar  9 2005 Paul Howarth <paul@city-fan.org> - 1.051-1
- Update to 1.051
- Update URL

* Wed Feb  9 2005 Paul Howarth <paul@city-fan.org> - 1.04-1
- Update to 1.04

* Wed Oct 27 2004 Paul Howarth <paul@city-fan.org> - 1.03-1
- Update to 1.03
- Tidy up spec file

* Thu Apr 15 2004 Paul Howarth <paul@city-fan.org> 1.0-3
- Added explicit perl dependency to ensure that an RPM built on a
  system with an updated version of perl (and hence having files
  installed in a place that a non-updated system won't find them)
  will not install on the non-updated system. In such cases, just
  rebuild from the source RPM
- Changed distribution-identifying macros for greater portability

* Mon Feb 16 2004 Paul Howarth <paul@city-fan.org> - 1.0-2
- Unified spec file for Red Hat and Fedora Core

* Tue Feb 03 2004 Paul Howarth <paul@city-fan.org> - 1.0-1.fc1
- Initial RPM build
